@@ -1,10 +1,10 @@
-INSERT INTO version (table_name, table_version) values ('dialog','10');
+INSERT INTO version (table_name, table_version) values ('dialog','11');
 CREATE TABLE dialog (
     dlg_id BIGINT(10) UNSIGNED PRIMARY KEY NOT NULL,
     callid CHAR(255) NOT NULL,
-    from_uri CHAR(128) NOT NULL,
+    from_uri CHAR(255) NOT NULL,
     from_tag CHAR(64) NOT NULL,
-    to_uri CHAR(128) NOT NULL,
+    to_uri CHAR(255) NOT NULL,
     to_tag CHAR(64) NOT NULL,
     mangled_from_uri CHAR(64) DEFAULT NULL,
     mangled_to_uri CHAR(64) DEFAULT NULL,
@@ -14,8 +14,8 @@ CREATE TABLE dialog (
     callee_ping_cseq INT(11) UNSIGNED NOT NULL,
     caller_route_set TEXT(512),
     callee_route_set TEXT(512),
-    caller_contact CHAR(128) NOT NULL,
-    callee_contact CHAR(128) NOT NULL,
+    caller_contact CHAR(255),
+    callee_contact CHAR(255),
     caller_sock CHAR(64) NOT NULL,
     callee_sock CHAR(64) NOT NULL,
     state INT(10) UNSIGNED NOT NULL,
@@ -25,6 +25,9 @@ CREATE TABLE dialog (
     profiles TEXT(512) DEFAULT NULL,
     script_flags INT(10) UNSIGNED DEFAULT 0 NOT NULL,
     module_flags INT(10) UNSIGNED DEFAULT 0 NOT NULL,
-    flags INT(10) UNSIGNED DEFAULT 0 NOT NULL
+    flags INT(10) UNSIGNED DEFAULT 0 NOT NULL,
+    rt_on_answer CHAR(64) DEFAULT NULL,
+    rt_on_timeout CHAR(64) DEFAULT NULL,
+    rt_on_hangup CHAR(64) DEFAULT NULL
 ) ENGINE=InnoDB;
 
